#line 2 "glsl/glsl_lexer.cpp"

#line 4 "glsl/glsl_lexer.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE _mesa_glsl_lexer_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via _mesa_glsl_lexer_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void _mesa_glsl_lexer_restart (FILE *input_file ,yyscan_t yyscanner );
void _mesa_glsl_lexer__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_glsl_lexer__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void _mesa_glsl_lexer__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _mesa_glsl_lexer__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _mesa_glsl_lexer_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void _mesa_glsl_lexer_pop_buffer_state (yyscan_t yyscanner );

static void _mesa_glsl_lexer_ensure_buffer_stack (yyscan_t yyscanner );
static void _mesa_glsl_lexer__load_buffer_state (yyscan_t yyscanner );
static void _mesa_glsl_lexer__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER _mesa_glsl_lexer__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE _mesa_glsl_lexer__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_glsl_lexer__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_glsl_lexer__scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *_mesa_glsl_lexer_alloc (yy_size_t ,yyscan_t yyscanner );
void *_mesa_glsl_lexer_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void _mesa_glsl_lexer_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer _mesa_glsl_lexer__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        _mesa_glsl_lexer_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _mesa_glsl_lexer__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        _mesa_glsl_lexer_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _mesa_glsl_lexer__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define _mesa_glsl_lexer_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yynoreturn yy_fatal_error (yyconst char* msg ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 267
#define YY_END_OF_BUFFER 268
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1048] =
    {   0,
        0,    0,   16,   16,    0,    0,  268,  266,    1,   23,
      266,  266,  266,  266,  266,  266,  265,  266,  180,  178,
      266,  266,  266,  264,  266,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  266,    1,  266,   22,   16,
       21,   22,   20,   19,   17,   18,   14,   13,    1,  162,
      171,  163,  174,  168,  157,  170,  158,  177,  182,  169,
      183,  180,    0,    0,  180,    0,  178,  178,  166,  159,
      161,  160,  167,  264,  175,  165,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,

       32,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,   36,  264,  264,   63,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  176,  164,    1,    0,    0,    2,    0,    0,
        0,    0,   16,   15,   19,   18,    0,  182,    0,    0,
      181,    0,  183,    0,    0,    0,  184,  179,  172,  173,
      264,  191,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,

      264,  264,  264,  264,  264,  264,  264,   35,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,   28,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
       64,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,    0,    0,    0,
        0,   15,    0,  182,  186,    0,  181,    0,    0,    0,
      183,  187,  184,    0,    0,  179,  264,  264,  264,   26,
      264,  264,  264,  249,  242,  264,  264,  264,  264,  264,

      264,  264,  264,  264,  264,  264,   34,  194,  264,  264,
      264,  264,   71,  264,  264,  199,  212,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  209,
      245,   51,   52,   53,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      197,  189,  264,  264,   29,  264,  264,  264,  264,  264,
      264,  264,   48,   49,   50,  155,  264,  264,  264,    0,
        0,    0,    0,    0,  181,  185,  188,  264,  264,  264,
       30,  264,   39,   40,   41,  264,  192,  264,  264,   25,

      264,  264,  264,  223,  224,  225,  264,  220,  221,  222,
      264,  190,  264,  213,   27,  235,  236,  237,  247,  217,
      218,  219,  264,  264,  264,   65,  215,  264,  264,  264,
       42,   43,   44,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,   74,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  210,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  193,  264,  264,  244,
       45,   46,   47,  264,  264,   33,  264,    0,    0,    0,
        0,  252,  264,  264,   67,  264,  264,  250,  264,  264,
      264,  264,  264,  264,  211,  206,  255,  264,  264,  264,

      264,  264,  264,  202,  264,  264,  264,  156,   54,   55,
       56,   57,   58,   59,   60,   61,   62,  264,  264,  264,
      264,  216,  198,  264,  264,  204,  264,  264,  264,   38,
      264,  262,  153,  241,   72,  205,  154,  264,  253,  200,
      264,  264,  264,  264,  264,  264,  264,  264,  264,    0,
        0,    0,    0,  264,  264,  264,  264,  264,  201,   37,
      226,  227,  228,  229,  230,  231,  232,  233,  234,  264,
      264,  264,  264,  264,  264,  110,  111,  112,  264,  264,
      264,  264,  264,  246,  264,  264,  264,  264,  109,  264,
      264,  264,  264,  264,  264,  264,  264,  195,  264,  264,

      264,  264,  264,   66,  264,  264,   68,  264,  264,    0,
        0,    0,    0,    0,  264,  264,   69,  147,   31,  207,
      121,  122,  123,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  203,  264,  264,
      264,  150,  261,  149,  264,  264,  264,  264,  264,  264,
      264,  264,  196,  132,  133,  134,  264,  264,  214,  264,
      148,  264,    0,    0,    6,    0,    0,    0,   12,    3,
      264,   24,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  119,  264,  264,  264,  114,  208,   70,  264,  264,
      264,  264,  264,  243,  264,  251,  248,  256,   75,   76,

       77,  264,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  151,    0,    0,    0,
        0,    0,    0,    0,  264,  264,  264,  130,  264,  264,
      125,  264,  264,  264,  264,  264,  264,  264,  264,   86,
       87,   88,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  263,  264,  264,  141,  264,
      264,  136,   92,   93,   94,  264,  264,    4,    0,    5,
        0,    0,    0,    0,    0,    0,  152,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  113,  264,  115,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,

      264,   98,  264,  264,  264,  264,   78,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  264,  264,  264,
        0,    0,    0,    0,  264,  264,  264,  124,  126,  264,
      116,  264,  117,  264,  264,  264,  264,  264,   99,  264,
      264,   89,  264,  264,  264,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  264,  135,  137,  264,
      264,  264,  100,  264,  264,   95,    0,    0,    0,  127,
      128,  264,  264,  264,  143,  264,  264,  144,  264,  264,
      264,  264,  264,  264,  264,   73,  264,  264,  264,  264,
      238,  264,  239,  254,  264,  264,  264,  138,  139,  264,

      264,  264,  264,  264,  264,  264,  264,    0,    0,    0,
      264,  264,  264,  264,  120,  118,  264,  264,  264,  257,
      259,  264,   79,  264,   80,  264,  264,  264,  264,  264,
      264,  264,  264,  264,  264,  264,  258,  260,  264,    0,
        0,    0,    0,  131,  129,  264,  264,   90,   91,  264,
      264,  264,   81,  264,  264,  264,   82,  264,  264,  264,
      142,  140,   96,   97,  264,  264,    0,    0,    0,    0,
      264,  264,  264,  264,  264,  264,  101,  264,  104,  264,
      264,  264,  264,    0,    0,    0,    0,  264,  264,  102,
      105,  264,  264,  264,  264,   83,  264,  103,  106,    0,

        0,    0,    7,    0,    0,  145,  146,  264,  264,  264,
      264,  108,    0,    0,    8,    0,    0,  264,  264,  240,
      264,    0,    0,    0,   84,   85,  264,    0,    0,    0,
        9,  264,    0,    0,   10,  107,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   11,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    1,    6,    1,    7,    8,    1,    9,
       10,   11,   12,    1,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   21,   21,   22,   22,   23,    1,   24,
       25,   26,    1,    1,   27,   28,   29,   30,   31,   32,
       33,   34,   34,   34,   34,   35,   36,   34,   37,   34,
       34,   38,   39,   40,   41,   34,   34,   42,   34,   34,
        1,    1,    1,   43,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   60,   34,   61,   62,   63,   64,   65,   66,   67,
       68,   69,    1,   70,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[71] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    3,    1,    1,    1,    1,    4,    4,    4,    4,
        4,    3,    5,    5,    6,    5,    5,    5,    5,    5,
        5,    5,    1,    5,    4,    4,    4,    4,    4,    3,
        5,    5,    5,    5,    5,    6,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    1
    } ;

static yyconst flex_uint16_t yy_base[1060] =
    {   0,
        0,   69,   75,  145, 1418, 1417, 1419, 1422,   70, 1422,
     1393, 1392,   94, 1391,   91,   92,   90, 1390,  202,  256,
       89, 1389,   95,    0,   79,   68,   64,  127,  125,   68,
      136, 1354,  132,  141,   82,   87,  128, 1348,  148,   84,
      182,  179,  149,  151,  152,  109,  136,  234, 1422,  135,
     1422, 1396, 1422,  236, 1422,    0, 1422, 1422,  228, 1422,
     1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,  305, 1422,
      346,  138,  297,  331, 1422,    0,    0, 1422, 1385, 1422,
     1422, 1422, 1384,    0, 1422, 1422, 1345, 1350,  166, 1347,
     1356, 1354, 1354, 1340, 1343, 1355,  207, 1349, 1336, 1352,

     1332, 1346, 1332, 1329, 1329, 1335,  182,  222, 1329, 1340,
     1325, 1331, 1335, 1336,    0, 1327, 1338,  226, 1337, 1332,
     1312,  184, 1316, 1330, 1320,  208, 1313,  232, 1326, 1328,
      239, 1307, 1315,  247, 1302, 1311,  235,  252, 1316, 1311,
     1314, 1302, 1305,  205,  155,  255, 1315, 1302, 1315,  251,
     1308, 1307, 1422, 1422,  327,  354,  356, 1422, 1292, 1305,
     1296, 1307,  328,    0,  353,    0,  367, 1422, 1323, 1304,
      359,  410, 1422, 1321, 1302,  417,  408,  335, 1422, 1422,
     1298,    0, 1293, 1288, 1292, 1302, 1296, 1298,  343, 1281,
     1281, 1293, 1284,  247, 1295, 1292, 1275, 1291, 1289, 1286,

     1277, 1284, 1270, 1268, 1281, 1266, 1283,    0, 1280, 1267,
     1275, 1272, 1276, 1277, 1270, 1267, 1255, 1254, 1268, 1271,
     1258, 1267, 1254, 1261, 1251,  426, 1257, 1260, 1250, 1258,
     1246, 1250, 1241, 1256, 1255, 1245, 1252,  275, 1235, 1254,
     1237, 1235, 1234, 1245, 1234, 1229, 1227, 1229, 1240, 1225,
     1227, 1224, 1236, 1235, 1238, 1219,  348, 1228, 1223, 1221,
     1231, 1209,  429, 1228, 1230, 1218, 1210, 1209, 1213, 1225,
     1208,    0,  434,  425, 1422,  449, 1422, 1236, 1217,  466,
      441, 1422, 1422, 1234, 1215, 1422, 1199, 1210, 1209,    0,
     1206, 1211,  459,    0,    0, 1198, 1196, 1196, 1197, 1192,

     1201, 1189, 1207,  474, 1195,  480,    0,    0, 1189, 1200,
     1199, 1199,    0, 1183,  483,    0,    0, 1185,  486, 1193,
     1194, 1184, 1178, 1177, 1178, 1177, 1177,  489, 1172,    0,
        0, 1168, 1167, 1166, 1168, 1169, 1174, 1168, 1164, 1178,
     1173, 1173, 1171, 1170, 1163, 1157, 1159, 1158, 1161, 1161,
     1167, 1152, 1155, 1150, 1159, 1164, 1151, 1148, 1161, 1151,
        0,    0, 1158, 1154,    0, 1145, 1145, 1151, 1141, 1149,
      492, 1146,    0,    0,    0,    0, 1135, 1148, 1147, 1146,
     1145, 1142, 1130,  497,  488, 1422, 1422, 1142, 1143, 1143,
        0, 1127,    0,    0,    0, 1128,    0, 1137, 1127,    0,

     1126, 1127, 1121, 1114, 1113, 1112, 1129,    0,    0,    0,
     1119,    0, 1115,    0,    0,    0,    0,    0,    0,    0,
        0,    0, 1126,  507, 1125,    0,    0, 1123, 1119, 1115,
        0,    0,    0, 1107,  509,  512,  521, 1112, 1108, 1114,
     1104, 1102, 1116, 1100,    0, 1100, 1114, 1102, 1098, 1105,
     1099, 1111, 1106, 1106,    0, 1103, 1100, 1104, 1087, 1085,
     1088, 1095, 1101, 1096, 1095, 1082,    0, 1084, 1085,    0,
        0,    0,    0, 1082, 1086,    0, 1079, 1079, 1134, 1078,
     1081,    0, 1089, 1068,    0, 1078, 1072,    0, 1065, 1065,
     1079,  527,  530,  533,    0, 1081,    0,  537, 1095, 1094,

     1093, 1058, 1057,    0, 1075, 1074, 1069,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0, 1057, 1071, 1057,
     1054,    0,    0, 1060,  286,    0, 1056, 1064, 1063,    0,
     1055, 1047,    0,    0,    0,    0,    0, 1044,    0,    0,
     1043, 1055,  540, 1047, 1054, 1053, 1050, 1044, 1041, 1036,
      558, 1052, 1037, 1031, 1031, 1045, 1029, 1042,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0, 1034,
     1059, 1058, 1057, 1022, 1021,  374,  534,    0, 1034, 1037,
     1035, 1023, 1019,    0, 1032, 1029, 1028, 1017,    0, 1016,
     1006, 1024, 1009, 1012,  564, 1017, 1020,    0, 1038, 1037,

     1036, 1001, 1000,    0, 1015, 1001,    0, 1012, 1004, 1006,
      582,  588, 1056,  999, 1003, 1006,    0,    0,    0,    0,
     1027,  436,    0, 1003, 1006,  990,  998,  988, 1009,  998,
      994,  995,  995,  994,  979,  594,  992,    0,  993,  981,
      980,    0,    0,    0,  976, 1006, 1005, 1004,  969,  968,
      964,  972,    0, 1002,  589,    0,  978,  981,    0,  600,
        0,  958,  966,  618, 1422,  639,    0,  645,  629, 1422,
      966,    0,  962,  961,  982,  971,  969,  969,  956,  971,
      954,  987,  966,  967,  962,  983,    0,    0,  979,  978,
      977,  942,  941,    0,  941,    0,    0,    0,  494,  642,

      965,  952,  955,  937,  950,  937,  936,  957,  946,  944,
      944,  962,  961,  960,  925,  924,    0,  929,  673,  680,
      339,  946,  936,  924,  920,  921,  920,  953,  932,  929,
      950,  931,  927,  929,  912,  909,  923,  909,  908,  941,
      616,    0,  917,  920,  912,  903,  911,  901,  917,  906,
      900,  902,  898,  898,  895,    0,  882,  876,  884,  863,
      860,  881,  880,  668,    0,  856,  859, 1422,  415, 1422,
      705,    0,  711,  874,  857,  838,    0,  855,  854,  837,
      834,  835,  834,  826,  834,  824,  830,    0,  830,    0,
      827,  826,  825,  844,  833,  831,  831,  814,  817,   28,

       83,  148,  179,  196,  213,  222,  495,  227,  258,  300,
      299,  319,  332,  336,  339,  343,  372,  371,  374,  376,
      439,  426,  416,  436,  422,  427,  435,    0,    0,  476,
      503,  477,  523,  518,  498,  522,  510,  525,  560,  541,
      540,  567,  547,  552,  566,  570,  565,  567,  584,  570,
      583,  584,  594,  592,  583,  585,  609,    0,    0,  610,
      611,  612,  647,  632,  635,  658,  651,  636,  646,    0,
        0,  660,  664,  658,    0,  659,  644,    0,  648,  672,
      673,  658,  657,  673,  674,    0,  668,  678,  670,  678,
      702,  683,    0,    0,  682,  699,  700,    0,    0,  701,

      702,  703,  704,  689,  688,  691,  692,  752,  753,  703,
      689,  690,  714,  715,    0,    0,  693,  695,  703,    0,
        0,  704,  727,  701,  729,  724,  718,  705,  727,  725,
      718,  707,  708,  709,  710,  718,    0,    0,  719,  779,
      780,  781,  715,    0,    0,  737,  738,    0,    0,  742,
      743,  738,    0,  739,  724,  748,    0,  726,  736,  759,
        0,    0,    0,    0,  752,  753,  741,  798,  751,  753,
      744,  745,  737,  738,  762,  763,    0,  762,  772,  746,
      782,  746,  747,  751,  767,  816,  818,  753,  755,    0,
        0,  774,  775,  765,  773,    0,  789,    0,    0,  784,

      828,  829, 1422,  832,  831,    0,    0,  776,  777,  771,
      797,    0,  782,  842, 1422,  843,  796,  781,  782,    0,
      801,  797,  801,  851,    0,    0,  796,  811,  856,  857,
     1422,  794,  804,  861, 1422,    0,  801,  863,  866,  867,
      868,  817,  818,  874,  875, 1422, 1422,  913,  919,  923,
      927,  931,  935,  939,  943,  947,  951,  955,  957
    } ;

static yyconst flex_int16_t yy_def[1060] =
    {   0,
     1047,    1, 1048, 1048, 1049, 1049, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1050, 1047, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1051, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047,   19, 1047, 1047, 1047, 1052,   20, 1047, 1047, 1047,
     1047, 1047, 1047, 1050, 1047, 1047, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1053, 1047, 1051, 1047, 1047, 1047, 1047,
       71, 1047, 1047, 1047, 1047, 1047, 1054, 1052, 1047, 1047,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047,
     1047, 1053, 1047, 1055, 1047, 1047, 1047, 1047, 1047, 1047,
     1056, 1047, 1047, 1047, 1047, 1047, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047,
     1047, 1047, 1047, 1047, 1057, 1047, 1047, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047,
     1047, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047,
     1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047,
     1047, 1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1047, 1047, 1047, 1047, 1058, 1047, 1047, 1047,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047,
     1058, 1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047,
     1047, 1059, 1047, 1047, 1047, 1047, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1059, 1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,

     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047,
     1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1047, 1047, 1047, 1047,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1050, 1047, 1047, 1047, 1047, 1050, 1050, 1050,
     1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1050, 1047,

     1047, 1047, 1047, 1047, 1047, 1050, 1050, 1050, 1050, 1050,
     1050, 1050, 1047, 1047, 1047, 1047, 1047, 1050, 1050, 1050,
     1050, 1047, 1047, 1047, 1050, 1050, 1050, 1047, 1047, 1047,
     1047, 1050, 1047, 1047, 1047, 1050, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047,    0, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047
    } ;

static yyconst flex_uint16_t yy_nxt[1493] =
    {   0,
        8,    9,   10,    9,   11,    8,   12,   13,    8,    8,
       14,   15,   16,   17,   18,   19,   20,   20,   20,   20,
       20,   20,    8,   21,   22,   23,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   25,   24,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   24,   24,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   24,   24,   24,   46,
       47,   59,  845,   59,   48,   49,   50,   51,   50,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   52,
       53,   54,   54,   54,   54,   54,   54,   55,   49,   49,

       49,   62,   65,   85,   67,   69,   69,   69,   69,   69,
       69,   69,   79,   80,   87,   66,   68,   49,   63,   82,
       83,   86,   90,  103,   91,  104,  121,   92,   93,   88,
       89,  123,  131,  153,  105,  124,  163,  155,  163,   59,
      122,  156,  132,  846,   49,   49,   50,   51,   50,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   52,
       53,   54,   54,   54,   54,   54,   54,   55,   49,   49,
       49,   94,  125,   98,  847,   95,  112,   99,  154, 1047,
      106,  100,   96,  101,  113,   97,  126,   49,  107,  102,
      115,  108,  128,  116,  109,  148,  114,  117,  118,  149,

      110,  144,  119,  151, 1047,  120,  145,  257,  129,  150,
      146,  130,  152,  147,   49,   71,  258,   72,   72,   72,
       72,   72,   72,   73,  183,  848,  133,  140,  184,   59,
      141,   59,   74,  134,  135,  157,  158,  204,  136,  142,
      849,  224,   75,   76,  137,  138,  143,  139,  205,  225,
       74,  165,  165,  165,  165,  165,  165,  165,  192,  850,
      229,  255,  256,  193,  194,   75,  206,  230,   76,   71,
      851,   77,   77,   77,   77,   77,   77,   77,  232,  246,
      207,  216,  159,  237,  217,  218,   74,  854,  219,  160,
      220,  242,  233,  161,  234,  247,   78,  248,  162,  259,

      238,  239,  855,  264,   74,  243,  265,  260,  300,  301,
       71,  249,   73,   73,   73,   73,   73,   73,   73,   78,
       69,   69,   69,   69,   69,   69,   69,   74,  155,  163,
       59,  163,  156,  346,  589,  167,  168,  347,  590,  169,
      664,  665,  176,  176,  856,   74,  177,  177,  177,  177,
      177,  177,  177,  167,  168,  157,  158,  157,  158,  857,
      170,  171,  171,  171,  171,  171,  171,  171,  165,  165,
      165,  165,  165,  165,  165,  286,  172,  173,  273,  273,
      174,  858,  274,  274,  274,  274,  274,  274,  274,  276,
      277,  294,  859,  278,  172,  173,  860,  366,  286,  861,

      626,  175,  159,  862,  159,  295,  367,  276,  277,  160,
      863,  160,  627,  161,  279,  161,  769,  770,  162,  864,
      162,  280,  280,  865,  866,  281,  281,  281,  281,  281,
      281,  281,  177,  177,  177,  177,  177,  177,  177,  283,
      769,  770,  284,  332,  333,  334,  373,  374,  375,  274,
      274,  274,  274,  274,  274,  274,  168,  283,  867,  169,
      384,  384,  674,  285,  385,  385,  385,  385,  385,  385,
      385,  675,  173,  676,  168,  174,  393,  394,  395,  868,
      170,  281,  281,  281,  281,  281,  281,  281,  869,  870,
      173,  404,  405,  406,  871,  872,  175,  408,  409,  410,

      416,  417,  418,  420,  421,  422,  431,  432,  433,  471,
      472,  473,  385,  385,  385,  385,  385,  385,  385,  277,
      746,  852,  278,  499,  500,  501,  509,  510,  511,  512,
      513,  514,  747,  853,  502,  503,  873,  277,  515,  516,
      517,  874,  875,  279,  561,  562,  563,  564,  565,  566,
      567,  568,  569,  571,  572,  573,  599,  600,  601,  551,
      628,  876,  877,  878,  574,  575,  879,  602,  603,  629,
      880,  630,  631,  611,  612,  612,  612,  612,  612,  612,
      646,  647,  648,  664,  665,  881,  882,  883,  884,  664,
      665,  649,  650,  885,  651,  886,  887,  666,  666,  666,

      666,  666,  666,  668,  668,  668,  668,  668,  668,  668,
      689,  690,  691,  888,  889,  707,  712,  713,  714,  664,
      665,  692,  693,  667,  708,  890,  709,  715,  716,  891,
      669,  892,  893,  719,  720,  720,  720,  720,  720,  720,
      664,  665,  793,  894,  895,  896,  664,  665,  667,  897,
      898,  794,  899,  795,  666,  666,  666,  666,  666,  666,
      668,  668,  668,  668,  668,  668,  668,  722,  748,  900,
      901,  902,  903,  904,  769,  770,  723,  749,  905,  750,
      751,  769,  770,  906,  907,  908,  909,  724,  771,  771,
      771,  771,  771,  771,  816,  773,  773,  773,  773,  773,

      773,  773,  910,  817,  911,  818,  769,  770,  912,  913,
      914,  915,  769,  770,  772,  916,  917,  918,  919,  920,
      771,  771,  771,  771,  771,  771,  773,  773,  773,  773,
      773,  773,  773,  921,  922,  923,  924,  925,  926,  772,
      927,  928,  929,  930,  931,  932,  933,  934,  935,  936,
      937,  938,  939,  940,  941,  943,  944,  945,  946,  947,
      948,  942,  949,  950,  951,  952,  953,  954,  955,  956,
      957,  958,  959,  960,  961,  962,  963,  964,  965,  966,
      940,  941,  968,  970,  971,  972,  973,  974,  942,  975,
      976,  977,  978,  979,  980,  981,  982,  983,  984,  968,

      985,  987,  988,  989,  990,  991,  992,  993,  986,  994,
      995,  996,  997,  998,  999, 1000, 1001, 1002, 1006, 1004,
     1007, 1008, 1009, 1010, 1011, 1003, 1005, 1012, 1013, 1014,
     1002,  967, 1016, 1004, 1018, 1019, 1020, 1015, 1003,  969,
     1005, 1021, 1022, 1014, 1016, 1023, 1025, 1026, 1027, 1028,
     1029, 1015, 1030, 1024, 1032, 1033,  969, 1034, 1030, 1036,
     1031, 1037, 1034, 1038, 1039, 1035, 1031, 1039, 1041, 1041,
     1035, 1040, 1043, 1044, 1040, 1045, 1045,  844,  843,  842,
      841,  840,  839, 1046, 1046,  838,  837,  836,  835, 1017,
      834,  833,  832,  831,  830,  829,  828,  827,  826,  825,

      824, 1017,  823,  822,  820,  819,  815,  814,  813,  812,
      811, 1042, 1042,   56,   56,   56,   56,   56,   56,   57,
       57,   57,   57,   57,   57,   84,   84,   84,   84,  166,
      166,  166,  166,  178,  178,  272,  810,  272,  272,  272,
      272,  177,  809,  808,  177,  274,  807,  806,  274,  281,
      805,  804,  281,  385,  803,  802,  385,  721,  721,  821,
      821,  801,  800,  799,  798,  797,  796,  792,  791,  790,
      789,  788,  787,  786,  785,  784,  783,  782,  781,  780,
      779,  778,  777,  776,  775,  774,  768,  767,  766,  765,
      764,  763,  762,  761,  760,  759,  758,  757,  756,  755,

      754,  753,  752,  745,  744,  743,  742,  741,  740,  739,
      738,  737,  736,  735,  734,  733,  732,  731,  730,  729,
      728,  727,  726,  725,  718,  717,  711,  710,  706,  705,
      704,  703,  702,  701,  700,  699,  698,  697,  696,  695,
      694,  688,  687,  686,  685,  684,  683,  682,  681,  680,
      679,  678,  677,  673,  672,  671,  670,  669,  663,  662,
      661,  660,  659,  658,  657,  656,  655,  654,  653,  652,
      645,  644,  643,  642,  641,  640,  639,  638,  637,  636,
      635,  634,  633,  632,  625,  624,  623,  622,  621,  620,
      619,  618,  617,  616,  615,  614,  613,  610,  609,  608,

      607,  606,  605,  604,  598,  597,  596,  595,  594,  593,
      592,  591,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  570,  560,  559,  558,  557,
      556,  555,  554,  553,  552,  551,  550,  549,  548,  547,
      546,  545,  544,  543,  542,  541,  540,  539,  538,  537,
      536,  535,  534,  533,  532,  531,  530,  529,  528,  527,
      526,  525,  524,  523,  522,  521,  520,  519,  518,  508,
      507,  506,  505,  504,  498,  497,  496,  495,  494,  493,
      492,  491,  490,  489,  488,  487,  486,  485,  484,  483,
      482,  481,  480,  479,  478,  477,  476,  475,  474,  470,

      469,  468,  467,  466,  465,  464,  463,  462,  461,  460,
      459,  458,  457,  456,  455,  454,  453,  452,  451,  450,
      449,  448,  447,  446,  445,  444,  443,  442,  441,  440,
      439,  438,  437,  436,  435,  434,  430,  429,  428,  427,
      426,  425,  424,  423,  419,  415,  414,  413,  412,  411,
      407,  403,  402,  401,  400,  399,  398,  397,  396,  392,
      391,  390,  389,  388,  387,  387,  386,  386,  383,  382,
      381,  380,  379,  378,  377,  376,  372,  371,  370,  369,
      368,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  345,

      344,  343,  342,  341,  340,  339,  338,  337,  336,  335,
      331,  330,  329,  328,  327,  326,  325,  324,  323,  322,
      321,  320,  319,  318,  317,  316,  315,  314,  313,  312,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      299,  298,  297,  296,  293,  292,  291,  290,  289,  288,
      287,  282,  282,  275,  275,  271,  270,  269,  268,  267,
      266,  263,  262,  261,  254,  253,  252,  251,  250,  245,
      244,  241,  240,  236,  235,  231,  228,  227,  226,  223,
      222,  221,  215,  214,  213,  212,  211,  210,  209,  208,
      203,  202,  201,  200,  199,  198,  197,  196,  195,  191,

      190,  189,  188,  187,  186,  185,  182,  181,  180,  179,
      164,  127,  111,   81,   70,   64,   61,   60, 1047,   58,
       58,    7, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047

    } ;

static yyconst flex_int16_t yy_chk[1493] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        2,    9,  800,    9,    2,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,   13,   15,   25,   16,   17,   17,   17,   17,   17,
       17,   17,   21,   21,   26,   15,   16,    3,   13,   23,
       23,   25,   27,   30,   27,   30,   35,   27,   27,   26,
       26,   36,   40,   46,   30,   36,   50,   47,   50,   47,
       35,   47,   40,  801,    3,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,   28,   37,   29,  802,   28,   33,   29,   46,   72,
       31,   29,   28,   29,   33,   28,   37,    4,   31,   29,
       34,   31,   39,   34,   31,   44,   33,   34,   34,   44,

       31,   43,   34,   45,   72,   34,   43,  145,   39,   44,
       43,   39,   45,   43,    4,   19,  145,   19,   19,   19,
       19,   19,   19,   19,   89,  803,   41,   42,   89,   59,
       42,   59,   19,   41,   41,   48,   48,  107,   41,   42,
      804,  122,   19,   19,   41,   41,   42,   41,  107,  122,
       19,   54,   54,   54,   54,   54,   54,   54,   97,  805,
      126,  144,  144,   97,   97,   19,  108,  126,   19,   20,
      806,   20,   20,   20,   20,   20,   20,   20,  128,  137,
      108,  118,   48,  131,  118,  118,   20,  808,  118,   48,
      118,  134,  128,   48,  128,  137,   20,  138,   48,  146,

      131,  131,  809,  150,   20,  134,  150,  146,  194,  194,
       73,  138,   73,   73,   73,   73,   73,   73,   73,   20,
       69,   69,   69,   69,   69,   69,   69,   73,  155,  163,
      155,  163,  155,  238,  525,   69,   69,  238,  525,   69,
      721,  721,   74,   74,  810,   73,   74,   74,   74,   74,
       74,   74,   74,   69,   69,  156,  156,  157,  157,  811,
       69,   71,   71,   71,   71,   71,   71,   71,  165,  165,
      165,  165,  165,  165,  165,  178,   71,   71,  167,  167,
       71,  812,  167,  167,  167,  167,  167,  167,  167,  171,
      171,  189,  813,  171,   71,   71,  814,  257,  178,  815,

      576,   71,  156,  816,  157,  189,  257,  171,  171,  156,
      817,  157,  576,  156,  171,  157,  769,  769,  156,  818,
      157,  172,  172,  819,  820,  172,  172,  172,  172,  172,
      172,  172,  176,  176,  176,  176,  176,  176,  176,  177,
      821,  821,  177,  226,  226,  226,  263,  263,  263,  273,
      273,  273,  273,  273,  273,  273,  274,  177,  822,  274,
      276,  276,  622,  177,  276,  276,  276,  276,  276,  276,
      276,  622,  281,  622,  274,  281,  293,  293,  293,  823,
      274,  280,  280,  280,  280,  280,  280,  280,  824,  825,
      281,  304,  304,  304,  826,  827,  281,  306,  306,  306,

      315,  315,  315,  319,  319,  319,  328,  328,  328,  371,
      371,  371,  384,  384,  384,  384,  384,  384,  384,  385,
      699,  807,  385,  424,  424,  424,  435,  435,  435,  436,
      436,  436,  699,  807,  424,  424,  830,  385,  437,  437,
      437,  831,  832,  385,  492,  492,  492,  493,  493,  493,
      494,  494,  494,  498,  498,  498,  543,  543,  543,  551,
      577,  833,  834,  835,  498,  498,  836,  543,  543,  577,
      837,  577,  577,  551,  551,  551,  551,  551,  551,  551,
      595,  595,  595,  611,  611,  838,  839,  840,  841,  612,
      612,  595,  595,  842,  595,  843,  844,  611,  611,  611,

      611,  611,  611,  612,  612,  612,  612,  612,  612,  612,
      636,  636,  636,  845,  846,  655,  660,  660,  660,  664,
      664,  636,  636,  611,  655,  847,  655,  660,  660,  848,
      669,  849,  850,  664,  664,  664,  664,  664,  664,  664,
      666,  666,  741,  851,  852,  853,  668,  668,  611,  854,
      855,  741,  856,  741,  666,  666,  666,  666,  666,  666,
      668,  668,  668,  668,  668,  668,  668,  669,  700,  857,
      860,  861,  862,  863,  719,  719,  669,  700,  864,  700,
      700,  720,  720,  865,  866,  867,  868,  669,  719,  719,
      719,  719,  719,  719,  764,  720,  720,  720,  720,  720,

      720,  720,  869,  764,  872,  764,  771,  771,  873,  874,
      876,  877,  773,  773,  719,  879,  880,  881,  882,  883,
      771,  771,  771,  771,  771,  771,  773,  773,  773,  773,
      773,  773,  773,  884,  885,  887,  888,  889,  890,  719,
      891,  892,  895,  896,  897,  900,  901,  902,  903,  904,
      905,  906,  907,  908,  909,  910,  911,  912,  913,  914,
      917,  909,  918,  919,  922,  923,  924,  925,  926,  927,
      928,  929,  930,  931,  932,  933,  934,  935,  936,  939,
      940,  941,  942,  943,  946,  947,  950,  951,  941,  952,
      954,  955,  956,  958,  959,  960,  965,  966,  967,  968,

      969,  970,  971,  972,  973,  974,  975,  976,  969,  978,
      979,  980,  981,  982,  983,  984,  985,  986,  988,  987,
      989,  992,  993,  994,  995,  986,  987,  997, 1000, 1001,
     1002,  940, 1005, 1004, 1008, 1009, 1010, 1001, 1002,  942,
     1004, 1011, 1013, 1014, 1016, 1017, 1018, 1019, 1021, 1022,
     1023, 1014, 1024, 1017, 1027, 1028,  968, 1029, 1030, 1032,
     1024, 1033, 1034, 1037, 1038, 1029, 1030, 1039, 1040, 1041,
     1034, 1038, 1042, 1043, 1039, 1044, 1045,  799,  798,  797,
      796,  795,  794, 1044, 1045,  793,  792,  791,  789, 1005,
      787,  786,  785,  784,  783,  782,  781,  780,  779,  778,

      776, 1016,  775,  774,  767,  766,  763,  762,  761,  760,
      759, 1040, 1041, 1048, 1048, 1048, 1048, 1048, 1048, 1049,
     1049, 1049, 1049, 1049, 1049, 1050, 1050, 1050, 1050, 1051,
     1051, 1051, 1051, 1052, 1052, 1053,  758, 1053, 1053, 1053,
     1053, 1054,  757,  755, 1054, 1055,  754,  753, 1055, 1056,
      752,  751, 1056, 1057,  750,  749, 1057, 1058, 1058, 1059,
     1059,  748,  747,  746,  745,  744,  743,  740,  739,  738,
      737,  736,  735,  734,  733,  732,  731,  730,  729,  728,
      727,  726,  725,  724,  723,  722,  718,  716,  715,  714,
      713,  712,  711,  710,  709,  708,  707,  706,  705,  704,

      703,  702,  701,  695,  693,  692,  691,  690,  689,  686,
      685,  684,  683,  682,  681,  680,  679,  678,  677,  676,
      675,  674,  673,  671,  663,  662,  658,  657,  654,  652,
      651,  650,  649,  648,  647,  646,  645,  641,  640,  639,
      637,  635,  634,  633,  632,  631,  630,  629,  628,  627,
      626,  625,  624,  621,  616,  615,  614,  613,  610,  609,
      608,  606,  605,  603,  602,  601,  600,  599,  597,  596,
      594,  593,  592,  591,  590,  588,  587,  586,  585,  583,
      582,  581,  580,  579,  575,  574,  573,  572,  571,  570,
      558,  557,  556,  555,  554,  553,  552,  550,  549,  548,

      547,  546,  545,  544,  542,  541,  538,  532,  531,  529,
      528,  527,  524,  521,  520,  519,  518,  507,  506,  505,
      503,  502,  501,  500,  499,  496,  491,  490,  489,  487,
      486,  484,  483,  481,  480,  479,  478,  477,  475,  474,
      469,  468,  466,  465,  464,  463,  462,  461,  460,  459,
      458,  457,  456,  454,  453,  452,  451,  450,  449,  448,
      447,  446,  444,  443,  442,  441,  440,  439,  438,  434,
      430,  429,  428,  425,  423,  413,  411,  407,  406,  405,
      404,  403,  402,  401,  399,  398,  396,  392,  390,  389,
      388,  383,  382,  381,  380,  379,  378,  377,  372,  370,

      369,  368,  367,  366,  364,  363,  360,  359,  358,  357,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  347,
      346,  345,  344,  343,  342,  341,  340,  339,  338,  337,
      336,  335,  334,  333,  332,  329,  327,  326,  325,  324,
      323,  322,  321,  320,  318,  314,  312,  311,  310,  309,
      305,  303,  302,  301,  300,  299,  298,  297,  296,  292,
      291,  289,  288,  287,  285,  284,  279,  278,  271,  270,
      269,  268,  267,  266,  265,  264,  262,  261,  260,  259,
      258,  256,  255,  254,  253,  252,  251,  250,  249,  248,
      247,  246,  245,  244,  243,  242,  241,  240,  239,  237,

      236,  235,  234,  233,  232,  231,  230,  229,  228,  227,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  207,  206,  205,
      204,  203,  202,  201,  200,  199,  198,  197,  196,  195,
      193,  192,  191,  190,  188,  187,  186,  185,  184,  183,
      181,  175,  174,  170,  169,  162,  161,  160,  159,  152,
      151,  149,  148,  147,  143,  142,  141,  140,  139,  136,
      135,  133,  132,  130,  129,  127,  125,  124,  123,  121,
      120,  119,  117,  116,  114,  113,  112,  111,  110,  109,
      106,  105,  104,  103,  102,  101,  100,   99,   98,   96,

       95,   94,   93,   92,   91,   90,   88,   87,   83,   79,
       52,   38,   32,   22,   18,   14,   12,   11,    7,    6,
        5, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047, 1047,
     1047, 1047

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "./glsl/glsl_lexer.ll"
#line 2 "./glsl/glsl_lexer.ll"
/*
 * Copyright © 2008, 2009 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
#include <ctype.h>
#include <limits.h>
#include "util/strtod.h"
#include "ast.h"
#include "glsl_parser_extras.h"
#include "glsl_parser.h"

static int classify_identifier(struct _mesa_glsl_parse_state *, const char *);

#ifdef _MSC_VER
#define YY_NO_UNISTD_H
#endif

#define YY_USER_ACTION						\
   do {								\
      yylloc->first_column = yycolumn + 1;			\
      yylloc->first_line = yylloc->last_line = yylineno + 1;	\
      yycolumn += yyleng;					\
      yylloc->last_column = yycolumn + 1;			\
   } while(0);

#define YY_USER_INIT yylineno = 0; yycolumn = 0; yylloc->source = 0;

/* A macro for handling reserved words and keywords across language versions.
 *
 * Certain words start out as identifiers, become reserved words in
 * later language revisions, and finally become language keywords.
 * This may happen at different times in desktop GLSL and GLSL ES.
 *
 * For example, consider the following lexer rule:
 * samplerBuffer       KEYWORD(130, 0, 140, 0, SAMPLERBUFFER)
 *
 * This means that "samplerBuffer" will be treated as:
 * - a keyword (SAMPLERBUFFER token)         ...in GLSL >= 1.40
 * - a reserved word - error                 ...in GLSL >= 1.30
 * - an identifier                           ...in GLSL <  1.30 or GLSL ES
 */
#define KEYWORD(reserved_glsl, reserved_glsl_es,			\
                allowed_glsl, allowed_glsl_es, token)			\
   KEYWORD_WITH_ALT(reserved_glsl, reserved_glsl_es,			\
                    allowed_glsl, allowed_glsl_es, false, token)

/**
 * Like the KEYWORD macro, but the word is also treated as a keyword
 * if the given boolean expression is true.
 */
#define KEYWORD_WITH_ALT(reserved_glsl, reserved_glsl_es,		\
                         allowed_glsl, allowed_glsl_es,			\
                         alt_expr, token)				\
   do {									\
      if (yyextra->is_version(allowed_glsl, allowed_glsl_es)		\
          || (alt_expr)) {						\
	 return token;							\
      } else if (yyextra->is_version(reserved_glsl,			\
                                     reserved_glsl_es)) {		\
	 _mesa_glsl_error(yylloc, yyextra,				\
			  "illegal use of reserved word `%s'", yytext);	\
	 return ERROR_TOK;						\
      } else {								\
	 void *mem_ctx = yyextra->linalloc;					\
	 yylval->identifier = linear_strdup(mem_ctx, yytext);		\
	 return classify_identifier(yyextra, yytext);			\
      }									\
   } while (0)

/**
 * A macro for handling keywords that have been present in GLSL since
 * its origin, but were changed into reserved words in GLSL 3.00 ES.
 */
#define DEPRECATED_ES_KEYWORD(token)					\
   do {									\
      if (yyextra->is_version(0, 300)) {				\
	 _mesa_glsl_error(yylloc, yyextra,				\
			  "illegal use of reserved word `%s'", yytext);	\
	 return ERROR_TOK;						\
      } else {								\
         return token;							\
      }									\
   } while (0)

static int
literal_integer(char *text, int len, struct _mesa_glsl_parse_state *state,
		YYSTYPE *lval, YYLTYPE *lloc, int base)
{
   bool is_uint = (text[len - 1] == 'u' ||
		   text[len - 1] == 'U');
   const char *digits = text;

   /* Skip "0x" */
   if (base == 16)
      digits += 2;

   unsigned long long value = strtoull(digits, NULL, base);

   lval->n = (int)value;

   if (value > UINT_MAX) {
      /* Note that signed 0xffffffff is valid, not out of range! */
      if (state->is_version(130, 300)) {
	 _mesa_glsl_error(lloc, state,
			  "literal value `%s' out of range", text);
      } else {
	 _mesa_glsl_warning(lloc, state,
			    "literal value `%s' out of range", text);
      }
   } else if (base == 10 && !is_uint && (unsigned)value > (unsigned)INT_MAX + 1) {
      /* Tries to catch unintentionally providing a negative value.
       * Note that -2147483648 is parsed as -(2147483648), so we don't
       * want to warn for INT_MAX.
       */
      _mesa_glsl_warning(lloc, state,
			 "signed literal value `%s' is interpreted as %d",
			 text, lval->n);
   }
   return is_uint ? UINTCONSTANT : INTCONSTANT;
}

#define LITERAL_INTEGER(base) \
   literal_integer(yytext, yyleng, yyextra, yylval, yylloc, base)

/* Note: When adding any start conditions to this list, you must also
* update the "Internal compiler error" catch-all rule near the end of
* this file. */

#line 1255 "glsl/glsl_lexer.cpp"

#define INITIAL 0
#define PP 1
#define PRAGMA 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct _mesa_glsl_parse_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int _mesa_glsl_lexer_lex_init (yyscan_t* scanner);

int _mesa_glsl_lexer_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int _mesa_glsl_lexer_lex_destroy (yyscan_t yyscanner );

int _mesa_glsl_lexer_get_debug (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE _mesa_glsl_lexer_get_extra (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *_mesa_glsl_lexer_get_in (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *_mesa_glsl_lexer_get_out (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_out  (FILE * _out_str ,yyscan_t yyscanner );

			int _mesa_glsl_lexer_get_leng (yyscan_t yyscanner );

char *_mesa_glsl_lexer_get_text (yyscan_t yyscanner );

int _mesa_glsl_lexer_get_lineno (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_lineno (int _line_number ,yyscan_t yyscanner );

int _mesa_glsl_lexer_get_column  (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_column (int _column_no ,yyscan_t yyscanner );

YYSTYPE * _mesa_glsl_lexer_get_lval (yyscan_t yyscanner );

void _mesa_glsl_lexer_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *_mesa_glsl_lexer_get_lloc (yyscan_t yyscanner );
    
        void _mesa_glsl_lexer_set_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int _mesa_glsl_lexer_wrap (yyscan_t yyscanner );
#else
extern int _mesa_glsl_lexer_wrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int _mesa_glsl_lexer_lex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int _mesa_glsl_lexer_lex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			_mesa_glsl_lexer_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				_mesa_glsl_lexer__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		_mesa_glsl_lexer__load_buffer_state(yyscanner );
		}

	{
#line 165 "./glsl/glsl_lexer.ll"


#line 1544 "glsl/glsl_lexer.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1048 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1047 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 167 "./glsl/glsl_lexer.ll"
;
	YY_BREAK
/* Preprocessor tokens. */ 
case 2:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 170 "./glsl/glsl_lexer.ll"
;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 171 "./glsl/glsl_lexer.ll"
{ BEGIN PP; return VERSION_TOK; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 172 "./glsl/glsl_lexer.ll"
{ BEGIN PP; return EXTENSION; }
	YY_BREAK
case 5:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 173 "./glsl/glsl_lexer.ll"
{
				   /* Eat characters until the first digit is
				    * encountered
				    */
				   char *ptr = yytext;
				   while (!isdigit(*ptr))
				      ptr++;

				   /* Subtract one from the line number because
				    * yylineno is zero-based instead of
				    * one-based.
				    */
				   yylineno = strtol(ptr, &ptr, 0) - 1;

                                   /* From GLSL 3.30 and GLSL ES on, after processing the
                                    * line directive (including its new-line), the implementation
                                    * will behave as if it is compiling at the line number passed
                                    * as argument. It was line number + 1 in older specifications.
                                    */
                                   if (yyextra->is_version(330, 100))
                                      yylineno--;

				   yylloc->source = strtol(ptr, NULL, 0);
				}
	YY_BREAK
case 6:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 197 "./glsl/glsl_lexer.ll"
{
				   /* Eat characters until the first digit is
				    * encountered
				    */
				   char *ptr = yytext;
				   while (!isdigit(*ptr))
				      ptr++;

				   /* Subtract one from the line number because
				    * yylineno is zero-based instead of
				    * one-based.
				    */
				   yylineno = strtol(ptr, &ptr, 0) - 1;

                                   /* From GLSL 3.30 and GLSL ES on, after processing the
                                    * line directive (including its new-line), the implementation
                                    * will behave as if it is compiling at the line number passed
                                    * as argument. It was line number + 1 in older specifications.
                                    */
                                   if (yyextra->is_version(330, 100))
                                      yylineno--;
				}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 219 "./glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_DEBUG_ON;
				}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 223 "./glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_DEBUG_OFF;
				}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 227 "./glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_OPTIMIZE_ON;
				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 231 "./glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_OPTIMIZE_OFF;
				}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 235 "./glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_INVARIANT_ALL;
				}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 239 "./glsl/glsl_lexer.ll"
{ BEGIN PRAGMA; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 241 "./glsl/glsl_lexer.ll"
{ BEGIN 0; yylineno++; yycolumn = 0; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 242 "./glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 244 "./glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 245 "./glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 246 "./glsl/glsl_lexer.ll"
return COLON;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 247 "./glsl/glsl_lexer.ll"
{
				   void *mem_ctx = yyextra->linalloc;
				   yylval->identifier = linear_strdup(mem_ctx, yytext);
				   return IDENTIFIER;
				}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 252 "./glsl/glsl_lexer.ll"
{
				    yylval->n = strtol(yytext, NULL, 10);
				    return INTCONSTANT;
				}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 256 "./glsl/glsl_lexer.ll"
{
				    yylval->n = 0;
				    return INTCONSTANT;
				}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 260 "./glsl/glsl_lexer.ll"
{ BEGIN 0; yylineno++; yycolumn = 0; return EOL; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 261 "./glsl/glsl_lexer.ll"
{ return yytext[0]; }
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 263 "./glsl/glsl_lexer.ll"
{ yylineno++; yycolumn = 0; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 265 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(ATTRIBUTE);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 266 "./glsl/glsl_lexer.ll"
return CONST_TOK;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 267 "./glsl/glsl_lexer.ll"
return BOOL_TOK;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 268 "./glsl/glsl_lexer.ll"
return FLOAT_TOK;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 269 "./glsl/glsl_lexer.ll"
return INT_TOK;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 270 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, UINT_TOK);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 272 "./glsl/glsl_lexer.ll"
return BREAK;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 273 "./glsl/glsl_lexer.ll"
return CONTINUE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 274 "./glsl/glsl_lexer.ll"
return DO;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 275 "./glsl/glsl_lexer.ll"
return WHILE;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 276 "./glsl/glsl_lexer.ll"
return ELSE;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 277 "./glsl/glsl_lexer.ll"
return FOR;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 278 "./glsl/glsl_lexer.ll"
return IF;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 279 "./glsl/glsl_lexer.ll"
return DISCARD;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 280 "./glsl/glsl_lexer.ll"
return RETURN;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 282 "./glsl/glsl_lexer.ll"
return BVEC2;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 283 "./glsl/glsl_lexer.ll"
return BVEC3;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 284 "./glsl/glsl_lexer.ll"
return BVEC4;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 285 "./glsl/glsl_lexer.ll"
return IVEC2;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 286 "./glsl/glsl_lexer.ll"
return IVEC3;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 287 "./glsl/glsl_lexer.ll"
return IVEC4;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 288 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, UVEC2);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 289 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, UVEC3);
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 290 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, UVEC4);
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 291 "./glsl/glsl_lexer.ll"
return VEC2;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 292 "./glsl/glsl_lexer.ll"
return VEC3;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 293 "./glsl/glsl_lexer.ll"
return VEC4;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 294 "./glsl/glsl_lexer.ll"
return MAT2X2;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 295 "./glsl/glsl_lexer.ll"
return MAT3X3;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 296 "./glsl/glsl_lexer.ll"
return MAT4X4;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 297 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT2X2);
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 298 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT2X3);
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 299 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT2X4);
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 300 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT3X2);
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 301 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT3X3);
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 302 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT3X4);
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 303 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT4X2);
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 304 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT4X3);
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 305 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, MAT4X4);
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 307 "./glsl/glsl_lexer.ll"
return IN_TOK;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 308 "./glsl/glsl_lexer.ll"
return OUT_TOK;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 309 "./glsl/glsl_lexer.ll"
return INOUT_TOK;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 310 "./glsl/glsl_lexer.ll"
return UNIFORM;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 311 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(0, 0, 430, 310, yyextra->ARB_shader_storage_buffer_object_enable, BUFFER);
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 312 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(VARYING);
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 313 "./glsl/glsl_lexer.ll"
KEYWORD(120, 300, 120, 300, CENTROID);
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 314 "./glsl/glsl_lexer.ll"
KEYWORD(120, 100, 120, 100, INVARIANT);
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 315 "./glsl/glsl_lexer.ll"
KEYWORD(130, 100, 130, 300, FLAT);
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 316 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, SMOOTH);
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 317 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, NOPERSPECTIVE);
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 318 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(0, 300, 400, 320, yyextra->has_tessellation_shader(), PATCH);
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 320 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(SAMPLER1D);
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 321 "./glsl/glsl_lexer.ll"
return SAMPLER2D;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 322 "./glsl/glsl_lexer.ll"
return SAMPLER3D;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 323 "./glsl/glsl_lexer.ll"
return SAMPLERCUBE;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 324 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, SAMPLER1DARRAY);
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 325 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, SAMPLER2DARRAY);
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 326 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(SAMPLER1DSHADOW);
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 327 "./glsl/glsl_lexer.ll"
return SAMPLER2DSHADOW;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 328 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, SAMPLERCUBESHADOW);
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 329 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, SAMPLER1DARRAYSHADOW);
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 330 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, SAMPLER2DARRAYSHADOW);
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 331 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, ISAMPLER1D);
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 332 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, ISAMPLER2D);
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 333 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, ISAMPLER3D);
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 334 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, ISAMPLERCUBE);
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 335 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, ISAMPLER1DARRAY);
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 336 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, ISAMPLER2DARRAY);
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 337 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, USAMPLER1D);
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 338 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, USAMPLER2D);
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 339 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, USAMPLER3D);
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 340 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, USAMPLERCUBE);
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 341 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 0, USAMPLER1DARRAY);
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 342 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, USAMPLER2DARRAY);
	YY_BREAK
/* additional keywords in ARB_texture_multisample, included in GLSL 1.50 */
/* these are reserved but not defined in GLSL 3.00 */
/* [iu]sampler2DMS are defined in GLSL ES 3.10 */
case 98:
YY_RULE_SETUP
#line 347 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, SAMPLER2DMS);
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 348 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, ISAMPLER2DMS);
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 349 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, USAMPLER2DMS);
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 350 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, SAMPLER2DMSARRAY);
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 351 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, ISAMPLER2DMSARRAY);
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 352 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, USAMPLER2DMSARRAY);
	YY_BREAK
/* keywords available with ARB_texture_cube_map_array_enable extension on desktop GLSL */
case 104:
YY_RULE_SETUP
#line 355 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, SAMPLERCUBEARRAY);
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 356 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, ISAMPLERCUBEARRAY);
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 357 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, USAMPLERCUBEARRAY);
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 358 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, SAMPLERCUBEARRAYSHADOW);
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 360 "./glsl/glsl_lexer.ll"
{
			  if (yyextra->OES_EGL_image_external_enable)
			     return SAMPLEREXTERNALOES;
			  else
			     return IDENTIFIER;
		}
	YY_BREAK
/* keywords available with ARB_gpu_shader5 */
case 109:
YY_RULE_SETUP
#line 368 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_gpu_shader5_enable || yyextra->EXT_gpu_shader5_enable || yyextra->OES_gpu_shader5_enable, PRECISE);
	YY_BREAK
/* keywords available with ARB_shader_image_load_store */
case 110:
YY_RULE_SETUP
#line 371 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IMAGE1D);
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 372 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IMAGE2D);
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 373 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IMAGE3D);
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 374 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IMAGE2DRECT);
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 375 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IMAGECUBE);
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 376 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, IMAGEBUFFER);
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 377 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IMAGE1DARRAY);
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 378 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IMAGE2DARRAY);
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 379 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, IMAGECUBEARRAY);
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 380 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IMAGE2DMS);
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 381 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IMAGE2DMSARRAY);
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 382 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IIMAGE1D);
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 383 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IIMAGE2D);
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 384 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IIMAGE3D);
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 385 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IIMAGE2DRECT);
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 386 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IIMAGECUBE);
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 387 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, IIMAGEBUFFER);
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 388 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IIMAGE1DARRAY);
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 389 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, IIMAGE2DARRAY);
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 390 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, IIMAGECUBEARRAY);
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 391 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IIMAGE2DMS);
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 392 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, IIMAGE2DMSARRAY);
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 393 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, UIMAGE1D);
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 394 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, UIMAGE2D);
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 395 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, UIMAGE3D);
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 396 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, UIMAGE2DRECT);
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 397 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, UIMAGECUBE);
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 398 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, UIMAGEBUFFER);
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 399 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, UIMAGE1DARRAY);
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 400 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable, UIMAGE2DARRAY);
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 401 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, UIMAGECUBEARRAY);
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 402 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, UIMAGE2DMS);
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 403 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable, UIMAGE2DMSARRAY);
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 404 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, IMAGE1DSHADOW);
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 405 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, IMAGE2DSHADOW);
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 406 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, IMAGE1DARRAYSHADOW);
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 407 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, IMAGE2DARRAYSHADOW);
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 409 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, COHERENT);
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 410 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, VOLATILE);
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 411 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, RESTRICT);
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 412 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, READONLY);
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 413 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, WRITEONLY);
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 415 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_atomic_counters_enable, ATOMIC_UINT);
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 417 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(430, 310, 430, 310, yyextra->ARB_compute_shader_enable, SHARED);
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 419 "./glsl/glsl_lexer.ll"
return STRUCT;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 420 "./glsl/glsl_lexer.ll"
return VOID_TOK;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 422 "./glsl/glsl_lexer.ll"
{
		  if ((yyextra->is_version(140, 300))
		      || yyextra->AMD_conservative_depth_enable
		      || yyextra->ARB_conservative_depth_enable
		      || yyextra->ARB_explicit_attrib_location_enable
		      || yyextra->ARB_explicit_uniform_location_enable
                      || yyextra->has_separate_shader_objects()
		      || yyextra->ARB_uniform_buffer_object_enable
		      || yyextra->ARB_fragment_coord_conventions_enable
                      || yyextra->ARB_shading_language_420pack_enable
                      || yyextra->ARB_compute_shader_enable
                      || yyextra->ARB_tessellation_shader_enable) {
		      return LAYOUT_TOK;
		   } else {
		      void *mem_ctx = yyextra->linalloc;
		      yylval->identifier = linear_strdup(mem_ctx, yytext);
		      return classify_identifier(yyextra, yytext);
		   }
		}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 442 "./glsl/glsl_lexer.ll"
return INC_OP;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 443 "./glsl/glsl_lexer.ll"
return DEC_OP;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 444 "./glsl/glsl_lexer.ll"
return LE_OP;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 445 "./glsl/glsl_lexer.ll"
return GE_OP;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 446 "./glsl/glsl_lexer.ll"
return EQ_OP;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 447 "./glsl/glsl_lexer.ll"
return NE_OP;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 448 "./glsl/glsl_lexer.ll"
return AND_OP;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 449 "./glsl/glsl_lexer.ll"
return OR_OP;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 450 "./glsl/glsl_lexer.ll"
return XOR_OP;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 451 "./glsl/glsl_lexer.ll"
return LEFT_OP;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 452 "./glsl/glsl_lexer.ll"
return RIGHT_OP;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 454 "./glsl/glsl_lexer.ll"
return MUL_ASSIGN;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 455 "./glsl/glsl_lexer.ll"
return DIV_ASSIGN;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 456 "./glsl/glsl_lexer.ll"
return ADD_ASSIGN;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 457 "./glsl/glsl_lexer.ll"
return MOD_ASSIGN;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 458 "./glsl/glsl_lexer.ll"
return LEFT_ASSIGN;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 459 "./glsl/glsl_lexer.ll"
return RIGHT_ASSIGN;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 460 "./glsl/glsl_lexer.ll"
return AND_ASSIGN;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 461 "./glsl/glsl_lexer.ll"
return XOR_ASSIGN;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 462 "./glsl/glsl_lexer.ll"
return OR_ASSIGN;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 463 "./glsl/glsl_lexer.ll"
return SUB_ASSIGN;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 465 "./glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(10);
			}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 468 "./glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(16);
			}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 471 "./glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(8);
			}
	YY_BREAK
case 181:
#line 476 "./glsl/glsl_lexer.ll"
case 182:
#line 477 "./glsl/glsl_lexer.ll"
case 183:
#line 478 "./glsl/glsl_lexer.ll"
case 184:
YY_RULE_SETUP
#line 478 "./glsl/glsl_lexer.ll"
{
			    struct _mesa_glsl_parse_state *state = yyextra;
			    char suffix = yytext[strlen(yytext) - 1];
			    if (!state->is_version(120, 300) &&
			        (suffix == 'f' || suffix == 'F')) {
			        _mesa_glsl_warning(yylloc, state,
			                           "Float suffixes are invalid in GLSL 1.10");
			    }
			    yylval->real = _mesa_strtof(yytext, NULL);
			    return FLOATCONSTANT;
			}
	YY_BREAK
case 185:
#line 491 "./glsl/glsl_lexer.ll"
case 186:
#line 492 "./glsl/glsl_lexer.ll"
case 187:
#line 493 "./glsl/glsl_lexer.ll"
case 188:
YY_RULE_SETUP
#line 493 "./glsl/glsl_lexer.ll"
{
			    if (!yyextra->is_version(400, 0) &&
			        !yyextra->ARB_gpu_shader_fp64_enable)
			        return ERROR_TOK;
			    yylval->dreal = _mesa_strtod(yytext, NULL);
			    return DOUBLECONSTANT;
			}
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 501 "./glsl/glsl_lexer.ll"
{
			    yylval->n = 1;
			    return BOOLCONSTANT;
			}
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 505 "./glsl/glsl_lexer.ll"
{
			    yylval->n = 0;
			    return BOOLCONSTANT;
			}
	YY_BREAK
/* Reserved words in GLSL 1.10. */
case 191:
YY_RULE_SETUP
#line 512 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, ASM);
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 513 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, CLASS);
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 514 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, UNION);
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 515 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, ENUM);
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 516 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, TYPEDEF);
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 517 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, TEMPLATE);
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 518 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, THIS);
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 519 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 140, 300, yyextra->ARB_uniform_buffer_object_enable, PACKED_TOK);
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 520 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, GOTO);
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 521 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 130, 300, SWITCH);
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 522 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 130, 300, DEFAULT);
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 523 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INLINE_TOK);
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 524 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, NOINLINE);
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 525 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, PUBLIC_TOK);
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 526 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, STATIC);
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 527 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, EXTERN);
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 528 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, EXTERNAL);
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 529 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INTERFACE);
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 530 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, LONG_TOK);
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 531 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SHORT_TOK);
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 532 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DOUBLE_TOK);
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 533 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HALF);
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 534 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FIXED_TOK);
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 535 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, UNSIGNED);
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 536 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INPUT_TOK);
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 537 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, OUTPUT);
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 538 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC2);
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 539 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC3);
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 540 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC4);
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 541 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DVEC2);
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 542 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DVEC3);
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 543 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DVEC4);
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 544 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT2X2);
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 545 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT3X3);
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 546 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT4X4);
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 547 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT2X2);
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 548 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT2X3);
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 549 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT2X4);
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 550 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT3X2);
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 551 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT3X3);
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 552 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT3X4);
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 553 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT4X2);
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 554 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT4X3);
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 555 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, DMAT4X4);
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 556 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC2);
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 557 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC3);
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 558 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC4);
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 559 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(SAMPLER2DRECT);
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 560 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SAMPLER3DRECT);
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 561 "./glsl/glsl_lexer.ll"
DEPRECATED_ES_KEYWORD(SAMPLER2DRECTSHADOW);
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 562 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SIZEOF);
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 563 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, CAST);
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 564 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, NAMESPACE);
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 565 "./glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, USING);
	YY_BREAK
/* Additional reserved words in GLSL 1.20. */
case 245:
YY_RULE_SETUP
#line 568 "./glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, LOWP);
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 569 "./glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, MEDIUMP);
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 570 "./glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, HIGHP);
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 571 "./glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, PRECISION);
	YY_BREAK
/* Additional reserved words in GLSL 1.30. */
case 249:
YY_RULE_SETUP
#line 574 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, CASE);
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 575 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, COMMON);
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 576 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, PARTITION);
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 577 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, ACTIVE);
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 578 "./glsl/glsl_lexer.ll"
KEYWORD(130, 100, 0, 0, SUPERP);
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 579 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, SAMPLERBUFFER);
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 580 "./glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, FILTER);
	YY_BREAK
case 256:
YY_RULE_SETUP
#line 581 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 0, 140, 0, yyextra->ARB_uniform_buffer_object_enable && !yyextra->es_shader, ROW_MAJOR);
	YY_BREAK
/* Additional reserved words in GLSL 1.40 */
case 257:
YY_RULE_SETUP
#line 584 "./glsl/glsl_lexer.ll"
KEYWORD(140, 300, 140, 0, ISAMPLER2DRECT);
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 585 "./glsl/glsl_lexer.ll"
KEYWORD(140, 300, 140, 0, USAMPLER2DRECT);
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 586 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(140, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, ISAMPLERBUFFER);
	YY_BREAK
case 260:
YY_RULE_SETUP
#line 587 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(140, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, USAMPLERBUFFER);
	YY_BREAK
/* Additional reserved words in GLSL ES 3.00 */
case 261:
YY_RULE_SETUP
#line 590 "./glsl/glsl_lexer.ll"
KEYWORD(420, 300, 0, 0, RESOURCE);
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 591 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 300, 400, 320, yyextra->ARB_gpu_shader5_enable || yyextra->OES_shader_multisample_interpolation_enable, SAMPLE);
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 592 "./glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 300, 400, 0, yyextra->ARB_shader_subroutine_enable, SUBROUTINE);
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 595 "./glsl/glsl_lexer.ll"
{
			    struct _mesa_glsl_parse_state *state = yyextra;
			    void *ctx = state->linalloc;
			    if (state->es_shader && strlen(yytext) > 1024) {
			       _mesa_glsl_error(yylloc, state,
			                        "Identifier `%s' exceeds 1024 characters",
			                        yytext);
			    } else {
			      yylval->identifier = linear_strdup(ctx, yytext);
			    }
			    return classify_identifier(state, yytext);
			}
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 608 "./glsl/glsl_lexer.ll"
{ struct _mesa_glsl_parse_state *state = yyextra;
			  state->is_field = true;
			  return DOT_TOK; }
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 612 "./glsl/glsl_lexer.ll"
{ return yytext[0]; }
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 614 "./glsl/glsl_lexer.ll"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3072 "glsl/glsl_lexer.cpp"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(PP):
case YY_STATE_EOF(PRAGMA):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * _mesa_glsl_lexer_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( _mesa_glsl_lexer_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of _mesa_glsl_lexer_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					_mesa_glsl_lexer_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			_mesa_glsl_lexer_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) _mesa_glsl_lexer_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1048 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1048 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 1047);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					_mesa_glsl_lexer_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( _mesa_glsl_lexer_wrap(yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void _mesa_glsl_lexer_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        _mesa_glsl_lexer_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            _mesa_glsl_lexer__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	_mesa_glsl_lexer__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	_mesa_glsl_lexer__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void _mesa_glsl_lexer__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		_mesa_glsl_lexer_pop_buffer_state();
	 *		_mesa_glsl_lexer_push_buffer_state(new_buffer);
     */
	_mesa_glsl_lexer_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	_mesa_glsl_lexer__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (_mesa_glsl_lexer_wrap()) processing, but the only time this flag
	 * is looked at is after _mesa_glsl_lexer_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void _mesa_glsl_lexer__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE _mesa_glsl_lexer__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) _mesa_glsl_lexer_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer__create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) _mesa_glsl_lexer_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer__create_buffer()" );

	b->yy_is_our_buffer = 1;

	_mesa_glsl_lexer__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with _mesa_glsl_lexer__create_buffer()
 * @param yyscanner The scanner object.
 */
    void _mesa_glsl_lexer__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		_mesa_glsl_lexer_free((void *) b->yy_ch_buf ,yyscanner );

	_mesa_glsl_lexer_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a _mesa_glsl_lexer_restart() or at EOF.
 */
    static void _mesa_glsl_lexer__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	_mesa_glsl_lexer__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then _mesa_glsl_lexer__init_buffer was _probably_
     * called from _mesa_glsl_lexer_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void _mesa_glsl_lexer__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		_mesa_glsl_lexer__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void _mesa_glsl_lexer_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	_mesa_glsl_lexer_ensure_buffer_stack(yyscanner);

	/* This block is copied from _mesa_glsl_lexer__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from _mesa_glsl_lexer__switch_to_buffer. */
	_mesa_glsl_lexer__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void _mesa_glsl_lexer_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	_mesa_glsl_lexer__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		_mesa_glsl_lexer__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void _mesa_glsl_lexer_ensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_mesa_glsl_lexer_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_mesa_glsl_lexer_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE _mesa_glsl_lexer__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) _mesa_glsl_lexer_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	_mesa_glsl_lexer__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to _mesa_glsl_lexer_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       _mesa_glsl_lexer__scan_bytes() instead.
 */
YY_BUFFER_STATE _mesa_glsl_lexer__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return _mesa_glsl_lexer__scan_bytes(yystr,(int) strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to _mesa_glsl_lexer_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE _mesa_glsl_lexer__scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) _yybytes_len + 2;
	buf = (char *) _mesa_glsl_lexer_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_glsl_lexer__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = _mesa_glsl_lexer__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in _mesa_glsl_lexer__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE _mesa_glsl_lexer_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int _mesa_glsl_lexer_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int _mesa_glsl_lexer_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *_mesa_glsl_lexer_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *_mesa_glsl_lexer_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int _mesa_glsl_lexer_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *_mesa_glsl_lexer_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void _mesa_glsl_lexer_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void _mesa_glsl_lexer_set_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "_mesa_glsl_lexer_set_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void _mesa_glsl_lexer_set_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "_mesa_glsl_lexer_set_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see _mesa_glsl_lexer__switch_to_buffer
 */
void _mesa_glsl_lexer_set_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void _mesa_glsl_lexer_set_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int _mesa_glsl_lexer_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void _mesa_glsl_lexer_set_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * _mesa_glsl_lexer_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void _mesa_glsl_lexer_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *_mesa_glsl_lexer_get_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void _mesa_glsl_lexer_set_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* _mesa_glsl_lexer_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int _mesa_glsl_lexer_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) _mesa_glsl_lexer_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* _mesa_glsl_lexer_lex_init_extra has the same functionality as _mesa_glsl_lexer_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to _mesa_glsl_lexer_alloc in
 * the yyextra field.
 */

int _mesa_glsl_lexer_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    _mesa_glsl_lexer_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) _mesa_glsl_lexer_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    _mesa_glsl_lexer_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from _mesa_glsl_lexer_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * _mesa_glsl_lexer_lex_init()
     */
    return 0;
}

/* _mesa_glsl_lexer_lex_destroy is for both reentrant and non-reentrant scanners. */
int _mesa_glsl_lexer_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		_mesa_glsl_lexer__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		_mesa_glsl_lexer_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	_mesa_glsl_lexer_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        _mesa_glsl_lexer_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * _mesa_glsl_lexer_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    _mesa_glsl_lexer_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *_mesa_glsl_lexer_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *_mesa_glsl_lexer_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void _mesa_glsl_lexer_free (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see _mesa_glsl_lexer_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 614 "./glsl/glsl_lexer.ll"



int
classify_identifier(struct _mesa_glsl_parse_state *state, const char *name)
{
   if (state->is_field) {
      state->is_field = false;
      return FIELD_SELECTION;
   }
   if (state->symbols->get_variable(name) || state->symbols->get_function(name))
      return IDENTIFIER;
   else if (state->symbols->get_type(name))
      return TYPE_IDENTIFIER;
   else
      return NEW_IDENTIFIER;
}

void
_mesa_glsl_lexer_ctor(struct _mesa_glsl_parse_state *state, const char *string)
{
   _mesa_glsl_lexer_lex_init_extra(state,& state->scanner);
   _mesa_glsl_lexer__scan_string(string,state->scanner);
}

void
_mesa_glsl_lexer_dtor(struct _mesa_glsl_parse_state *state)
{
   _mesa_glsl_lexer_lex_destroy(state->scanner);
}

